ceph_rust::ceph

Function rados_object_clone_range

pub fn rados_object_clone_range(
    ctx: rados_ioctx_t,
    dst_object_name: &str,
    dst_offset: u64,
    src_object_name: &str,
    src_offset: u64,
    length: usize,
) -> RadosResult<()>
Efficiently copy a portion of one object to another If the underlying filesystem on the OSD supports it, this will be a copy-on-write clone. The src and dest objects must be in the same pg. To ensure this, the io context should have a locator key set (see rados_ioctx_locator_set_key()).