ceph_rust::ceph

Function rados_object_read

pub fn rados_object_read(
    ctx: rados_ioctx_t,
    object_name: &str,
    fill_buffer: &mut Vec<u8>,
    read_offset: u64,
) -> RadosResult<i32>
Read data from an object. This fills the slice given and returns the amount of bytes read The io context determines the snapshot to read from, if any was set by rados_ioctx_snap_set_read(). Default read size is 64K unless you call Vec::with_capacity(1024*128) with a larger size.