pub fn rados_object_remove(
ctx: rados_ioctx_t,
object_name: &str,
) -> RadosResult<()>Expand description
Delete an object Note: This does not delete any snapshots of the object.
pub fn rados_object_remove(
ctx: rados_ioctx_t,
object_name: &str,
) -> RadosResult<()>Delete an object Note: This does not delete any snapshots of the object.