ceph_rust::ceph

Function rados_object_set_alloc_hint

pub fn rados_object_set_alloc_hint(
    ctx: rados_ioctx_t,
    object_name: &str,
    expected_object_size: u64,
    expected_write_size: u64,
) -> RadosResult<()>
Set allocation hint for an object This is an advisory operation, it will always succeed (as if it was submitted with a LIBRADOS_OP_FLAG_FAILOK flag set) and is not guaranteed to do anything on the backend.