pub fn rados_object_exec(
ctx: rados_ioctx_t,
object_name: &str,
class_name: &str,
method_name: &str,
input_buffer: &[u8],
output_buffer: &mut [u8],
) -> RadosResult<()>Expand description
Execute an OSD class method on an object The OSD has a plugin mechanism for performing complicated operations on an object atomically. These plugins are called classes. This function allows librados users to call the custom methods. The input and output formats are defined by the class. Classes in ceph.git can be found in src/cls subdirectories